Learn R Programming

ROCt (version 0.8)

rein.ratetable: Expected mortality of French patients with End Stage Kidney Disease (ESKD) in dialysis and registrited previously on waiting list for renal transplantation

Description

An object of the class ratetable which contains the expected mortality of French patients with End Stage Kidney Disease (ESKD) in dialysis and registered previously on waiting list for renal transplantation. It is an array with two dimensions: the time since the registry on waiting list and the patient profile at this baseline.

Usage

data(rein.ratetable)

Arguments

source

URL: http://www.soc-nephrologie.org/REIN/

Details

The organization of a ratetable object is described in details by Therneau (1999) and Pohar (2006). We have estimated these data by using the renal epidemiology and information network (REIN). A competing risk model was performed in order to deal with the loss of follow-up to the transplantation. The profile represents the concatenation of the significant binary variables associated with the mortality on waiting list. In order to obtain the same variable in your database, we have to concatenate the following values in the same order. These values are collected at the registration date: rl{ a. 1 if the patient is male and 0 if female. b. 1 if the time between the first dialysis and the registration is higher than 1 year and 0 otherwise. c. 1 if hemodialysis and 0 if peritoneal dialysis. d. 1 if the patient is diabetic and 0 otherwise. e. 1 if the patient had history of cardiac failure diabetic and 0 otherwise. f. 1 if the patient had history of vascular failure diabetic and 0 otherwise. g. 1 if the patient had history of cancer and 0 otherwise. h. 1 if the age of the patients is in between 40 and 60 years and 0 otherwise. i. 1 if the age of the patients is higher than 60 years and 0 otherwise. j. 1 if the calendar year at registration is strictly higher than 2007 and 0 }

References

Pohar M., Stare J. (2006) Relative survival analysis in R. Computer methods and programs in biomedicine, 81, 272-278.

Examples

Run this code
data(rein.ratetable)

is.ratetable(rein.ratetable)

Run the code above in your browser using DataLab