data(rein.ratetable)profile represents the concatenation of the significant binary variables associated with the mortality on waiting list. In order to obtain the same variable in your database, we have to concatenate the following values in the same order. These values are collected at the registration date:
data(rein.ratetable)
is.ratetable(rein.ratetable)Run the code above in your browser using DataLab